Functions to manage unit name aliases
Summary
Functions
Un-aliases the provided unit if there is one or return the argument unchanged.
Functions to manage unit name aliases
Un-aliases the provided unit if there is one or return the argument unchanged.